#
# spec file for package qtermwidget-qt5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt_ver 5

%define pack_summ Qt5 terminal widget

%define pack_desc QTermWidget is a project based on the KDE4 \
Konsole application whose goal is to provide a Unicode-\
enabled, embeddable Qt widget to be used as a built-in console (or \
terminal emulation widget). Though Konsole is able of getting embedded, \
it is possible to have Qt without KDE. The original \
Konsole code was rewritten entirely with using Qt only, and all \
code dealing with user interface parts and session management was \
removed.

Name:           qtermwidget-qt5
Version:        0.8.0
Release:        lp150.1.6
Summary:        %{pack_summ}
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            https://github.com/qterminal/qtermwidget
Source:         https://github.com/lxde/qtermwidget/releases/download/%{version}/qtermwidget-%{version}.tar.xz
BuildRequires:  cmake >= 3.0.2
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  utf8proc-devel
# If we want translations we need to have more dependencies
#BuildRequires:  lxqt-l10n
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6
BuildRequires:  lxqt-build-tools-devel >= 0.3.0

%description
%{pack_desc}

%package -n libqtermwidget%{qt_ver}-0
Summary:        %{pack_summ}
Group:          Development/Libraries/C and C++
Requires:       %{name}-data >= %{version}

%description -n libqtermwidget%{qt_ver}-0
%{pack_desc}

%package data
Summary:        QTermWidget data package
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       libqtermwidget%{qt_ver}-0 = %{version}

%description data
Data files for qtermwidget library.

%package devel
Summary:        QTermWidget devel package
Group:          Development/Libraries/C and C++
Requires:       libqtermwidget%{qt_ver}-0 = %{version}

%description devel
Development environment for qtermwidget library.

%prep
%setup -q -n qtermwidget-%{version}

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DPULL_TRANSLATIONS=no -DUSE_UTF8PROC=yes

make V=1 %{?_smp_mflags}

%install
%cmake_install

%post -n libqtermwidget%{qt_ver}-0 -p /sbin/ldconfig

%postun -n libqtermwidget%{qt_ver}-0 -p /sbin/ldconfig

%files -n libqtermwidget%{qt_ver}-0
%defattr(-,root,root)
%doc AUTHORS CHANGELOG LICENSE README.md
%{_libdir}/libqtermwidget*.so.*

%files data
%defattr(-,root,root)
%{_datadir}/qtermwidget%{qt_ver}

%files devel
%defattr(-,root,root)
%{_includedir}/qtermwidget%{qt_ver}
%{_libdir}/libqtermwidget*.so
%{_libdir}/pkgconfig/qtermwidget%{qt_ver}.pc
%{_datadir}/cmake/qtermwidget%{qt_ver}


%changelog
* Wed Oct 25 2017 mvetter@suse.com
- Add BuildRequire:
  * utf8proc-devel to have better utf8 support
  * Qt5LinguistTools new dependency
- Use switch to not use git to pull translations
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.8.0:
  * FIX: #46 fix vertical font truncation
  * bump versions
  * Really fallback to /bin/sh when $SHELL is missing or invalid
  * README: don't recommend building from source
  * Improve README
  * Don't export github templates
  * Support REP escape sequence defined in ECMA-48, section 8.3.103
  * Fix build issue related to utmpx in Mac OSX Sierra
  * Remove the deprecation notice
  * Handle DECSCUSR signals
  * Copied issue template
  * Update building instructions
  * Require Qt 5.6+
  * This commit allows the consumer of qtermwidget to capture the (#111)
  * Allow the terminal display to be smaller than the size hint (#123)
  * Backport Vt102 emulation fixes (#113)
  * Backport the default.keytab from Konsole
  * Fixes (#122)
  * Updated README, Added support for PyQT 5.7
  * Fix memory leak in hotspot (URLs & emails) detection
  * Adds superbuild support
  * Use target_compile_definitions() instead of add_definitions()
  * Update find_package() documentation
  * Use the lxqt_create_pkgconfig_file
  * Improve lxqt_translate_ts() use
  * Adds COMPONENT to the install files
  * Renames test app to example. Make it work
  * Drop include_directories() for in tree dirs
  * Use the CMake Targets way
  * Pack Utf8Proc stuff
  * Adds export header
  * Use LXQtCompilerSettings
  * Packs compile definitions
  * Adds package version file
  * Removes Qt4 stuff
  * Add translation mechanism
  * Use const iterators when possible.
  * Enable strict iterators for debug builds
  * TerminalDisplay: Make resizing "Size" translatable
  * Exposes receivedData signal to users of QTermWidget
  * Exposes sessions autoClose property to QTermWidget
* Wed Jan  4 2017 dap.darkness@gmail.com
- Updated to 0.7.1:
  * Bump patch version (#105);
  * Added a modified Breeze color scheme (#104);
  * Accept hex color strings as well (#101);
  * Remove the stale lib/README (#102);
  * Implement background images (#95);
  * Implement other BOX DRAWING characters (#98);
  * Preparations for context menu actions on URLs (#97);
  * Drop the ancient wcwidth impl. and use utf8proc if possible;
  * Remove widget size checks in setVTFont() (#86);
  * Delete unused tooltip code (#81);
  * Fix size of the array passed to memset() (#79).
* Sun Sep 25 2016 dap.darkness@gmail.com
- Updated to 0.7.0:
  * Remove support for Qt <= 5.4;
  * Remove Designer plugin;
  * Check CHANGELOG for additional information.
- %%%%cmake macro.
* Tue May 17 2016 jengelh@inai.de
- Trim storytelling from description.
* Sun Feb 28 2016 dap.darkness@gmail.com
- Updated to 0.6.0:
  * Full Qt 5 support;
  * Drag & Drop support;
  * Lots of bugfixes and cleanups.
* Wed Sep 17 2014 dap.darkness@gmail.com
- Initial build.
